==> huaweicloudsdkiam-3.0.46-py2.py3-none-any.whl: huaweicloudsdkiam/v3/model/keystone_list_mappings_response.py <==
# coding: utf-8

import pprint
import re

import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class KeystoneListMappingsResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'links': 'Links',
        'mappings': 'list[MappingResult]'
    }

    attribute_map = {
        'links': 'links',
        'mappings': 'mappings'
    }

    def __init__(self, links=None, mappings=None):
        """KeystoneListMappingsResponse - a model defined in huaweicloud sdk"""
        
        super(KeystoneListMappingsResponse, self).__init__()

        self._links = None
        self._mappings = None
        self.discriminator = None

        if links is not None:
            self.links = links
        if mappings is not None:
            self.mappings = mappings

    @property
    def links(self):
        """Gets the links of this KeystoneListMappingsResponse.


        :return: The links of this KeystoneListMappingsResponse.
        :rtype: Links
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this KeystoneListMappingsResponse.


        :param links: The links of this KeystoneListMappingsResponse.
        :type: Links
        """
        self._links = links

    @property
    def mappings(self):
        """Gets the mappings of this KeystoneListMappingsResponse.

        映射信息列表。

        :return: The mappings of this KeystoneListMappingsResponse.
        :rtype: list[MappingResult]
        """
        return self._mappings

    @mappings.setter
    def mappings(self, mappings):
        """Sets the mappings of this KeystoneListMappingsResponse.

        映射信息列表。

        :param mappings: The mappings of this KeystoneListMappingsResponse.
        :type: list[MappingResult]
        """
        self._mappings = mappings

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KeystoneListMappingsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiam-3.0.52-py2.py3-none-any.whl: huaweicloudsdkiam/v3/model/keystone_list_mappings_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class KeystoneListMappingsResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'links': 'Links',
        'mappings': 'list[MappingResult]'
    }

    attribute_map = {
        'links': 'links',
        'mappings': 'mappings'
    }

    def __init__(self, links=None, mappings=None):
        """KeystoneListMappingsResponse - a model defined in huaweicloud sdk"""
        
        super(KeystoneListMappingsResponse, self).__init__()

        self._links = None
        self._mappings = None
        self.discriminator = None

        if links is not None:
            self.links = links
        if mappings is not None:
            self.mappings = mappings

    @property
    def links(self):
        """Gets the links of this KeystoneListMappingsResponse.


        :return: The links of this KeystoneListMappingsResponse.
        :rtype: Links
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this KeystoneListMappingsResponse.


        :param links: The links of this KeystoneListMappingsResponse.
        :type: Links
        """
        self._links = links

    @property
    def mappings(self):
        """Gets the mappings of this KeystoneListMappingsResponse.

        映射信息列表。

        :return: The mappings of this KeystoneListMappingsResponse.
        :rtype: list[MappingResult]
        """
        return self._mappings

    @mappings.setter
    def mappings(self, mappings):
        """Sets the mappings of this KeystoneListMappingsResponse.

        映射信息列表。

        :param mappings: The mappings of this KeystoneListMappingsResponse.
        :type: list[MappingResult]
        """
        self._mappings = mappings

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KeystoneListMappingsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
